@@ -33,8 +33,8 @@ test_that("source argument", {
                "Invalid 'source' argument. 'source' is neither a data frame nor a string.")
   s <- "blabla"
   expect_error(check_user_input(gdp, unit_in, unit_out, source = s),
-               glue::glue("Invalid 'source' argument. If 'source' is a string, it must be one of the internal sources. \\
-                          Use print_source_info\\(\\) for information on available sources. \\
+               glue::glue("Invalid 'source' argument. If 'source' is a string, it must be one of the internal \\
+                          sources. Use print_source_info\\(\\) for information on available sources. \\
                           If you are trying to pass a custom source, pass the data frame directly, not its name."))
 
   # Following doesn't work in covr for some reason
@@ -43,8 +43,7 @@ test_that("source argument", {
                "Invalid 'source' argument. Required columns are:(.*)")
 })
 
-test_that("Abort with bad input", {
-
+test_that("with_regions argument", {
   gdp <- tibble::tibble("iso3c" = "EUR", "year" = 2010, "value" = 100)
   unit_in = "current Int$PPP"
   unit_out = "current US$MER"
@@ -64,9 +63,34 @@ test_that("Abort with bad input", {
   )
   s <- my_bad_source
   expect_error(check_user_input(gdp, unit_in, unit_out,  source = s, with_regions = with_regions))
+})
 
+test_that("replace_NAs argument", {
+
+  gdp <- tibble::tibble("iso3c" = "EUR", "year" = 2010, "value" = 100)
+  unit_in = "current Int$PPP"
+  unit_out = "current US$MER"
+  s <- wb_wdi
+
+  expect_error(check_user_input(gdp, unit_in, unit_out,  source = s, replace_NAs = 2, with_regions = NULL),
+               glue::glue("Invalid 'replace_NAs' argument. Has to be either NULL, 0, 1, no_conversion, linear, \\
+                          regional_average or a combination of the above."))
+  expect_error(check_user_input(gdp, unit_in, unit_out,  source = s, replace_NAs = c(0, 1), with_regions = NULL),
+               glue::glue("Invalid 'replace_NAs' argument. The only accepted combinations of arguments start with \\
+                          'linear', e.g. c\\('linear', 'no_conversion'\\)."))
+
+  expect_error(
+    check_user_input(gdp, unit_in, unit_out,  source = s, replace_NAs = "regional_average", with_regions = NULL),
+    glue::glue("Using 'regional_average' requires a region mapping. The 'with_regions' argument can't be NULL.")
+  )
+})
+
+test_that("boolean arguments", {
+
+  gdp <- tibble::tibble("iso3c" = "EUR", "year" = 2010, "value" = 100)
+  unit_in = "current Int$PPP"
+  unit_out = "current US$MER"
   s <- wb_wdi
-  expect_error(check_user_input(gdp, unit_in, unit_out,  source = s, replace_NAs = 2, with_regions = NULL))
 
   expect_error(check_user_input(gdp, unit_in, unit_out,  source = s,
                                 with_regions = NULL, replace_NAs = NULL, verbose = "blabla"))
@@ -81,3 +105,4 @@ test_that("Abort with bad input", {
     verbose = TRUE,
     return_cfs = "blabla"))
 })
+
